@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,7 @@
 // System headers
 #include <math.h>
 #include <string>
+#include <string.h>
 
 // Global implementation headers
 #include "bzfgl.h"
@@ -177,7 +178,7 @@ void FontManager::loadAll(std::string directory)
 
 	  fontFaces[faceID][pFont->getSize()] = pFont;
 	} else {
-	  DEBUG4("Font Texture load failed: %s\n", file.getOSName().c_str());
+	  logDebugMessage(4,"Font Texture load failed: %s\n", file.getOSName().c_str());
 	  delete(pFont);
 	}
       }
@@ -197,20 +198,20 @@ int FontManager::getFaceID(std::string faceName)
   int faceID = 0;
   if (faceItr == faceNames.end()) {
     // see if there is a default
-    DEBUG4("Requested font %s not found, trying Default\n", faceName.c_str());
+    logDebugMessage(4,"Requested font %s not found, trying Default\n", faceName.c_str());
     faceName = "DEFAULT";
     faceItr = faceNames.find(faceName);
     if (faceItr == faceNames.end()) {
       // see if we have arial
-      DEBUG4("Requested font %s not found, trying Arial\n", faceName.c_str());
+      logDebugMessage(4,"Requested font %s not found, trying Arial\n", faceName.c_str());
       faceName = "ARIAL";
       faceItr = faceNames.find(faceName);
       if (faceItr == faceNames.end()) {
 	// hell we are outta luck, you just get the first one
-	DEBUG4("Requested font %s not found, trying first-loaded\n", faceName.c_str());
+	logDebugMessage(4,"Requested font %s not found, trying first-loaded\n", faceName.c_str());
 	faceItr = faceNames.begin();
 	if (faceItr == faceNames.end()) {
-	  DEBUG2("No fonts loaded\n");
+	  logDebugMessage(2,"No fonts loaded\n");
 	  return -1;	// we must have NO fonts, so you are screwed no matter what
 	}
       }
@@ -228,7 +229,7 @@ int FontManager::getNumFaces(void)
 const char* FontManager::getFaceName(int faceID)
 {
   if ((faceID < 0) || (faceID > getNumFaces())) {
-    DEBUG2("Trying to fetch name for invalid Font Face ID %d\n", faceID);
+    logDebugMessage(2,"Trying to fetch name for invalid Font Face ID %d\n", faceID);
     return NULL;
   }
 
@@ -242,14 +243,14 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
     return;
 
   if ((faceID < 0) || (faceID > getNumFaces())) {
-    DEBUG2("Trying to draw with invalid Font Face ID %d\n", faceID);
+    logDebugMessage(2,"Trying to draw with invalid Font Face ID %d\n", faceID);
     return;
   }
 
   ImageFont* pFont = getClosestRealSize(faceID, size, size);
 
   if (!pFont) {
-    DEBUG2("Could not find applicable font size for rendering; font face ID %d, "
+    logDebugMessage(2,"Could not find applicable font size for rendering; font face ID %d, "
 	   "requested size %f\n", faceID, size);
     return;
   }
@@ -418,7 +419,7 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 	} else if (tmpText == ANSI_STR_NO_PULSATE) {
 	  pulsating = false;
 	} else {
-	  DEBUG2("ANSI Code %s not supported\n", tmpText.c_str());
+	  logDebugMessage(2,"ANSI Code %s not supported\n", tmpText.c_str());
 	}
       }
     }
@@ -452,14 +453,14 @@ float FontManager::getStrLength(int faceID, float size,	const std::string &text,
     return 0.0f;
 
   if ((faceID < 0) || (faceID > getNumFaces())) {
-    DEBUG2("Trying to find length of string for invalid Font Face ID %d\n", faceID);
+    logDebugMessage(2,"Trying to find length of string for invalid Font Face ID %d\n", faceID);
     return 0.0f;
   }
 
   ImageFont* pFont = getClosestRealSize(faceID, size, size);
 
   if (!pFont) {
-    DEBUG2("Could not find applicable font size for sizing; font face ID %d, "
+    logDebugMessage(2,"Could not find applicable font size for sizing; font face ID %d, "
 	   "requested size %f\n", faceID, size);
     return 0.0f;
   }
@@ -467,9 +468,13 @@ float FontManager::getStrLength(int faceID, float size,	const std::string &text,
   float scale = size / (float)pFont->getSize();
 
   // don't include ansi codes in the length, but allow outside funcs to skip this step
-  const std::string &stripped = alreadyStripped ? text : stripAnsiCodes(text);
-
-  return pFont->getStrLength(scale, stripped.c_str(), (int)stripped.size());
+  float strippedLength;
+  if (alreadyStripped) {
+    strippedLength = pFont->getStrLength(scale, text);
+  } else {
+    strippedLength = pFont->getStrLength(scale, stripAnsiCodes(text));
+  }
+  return strippedLength;
 }
 
 float FontManager::getStrLength(const std::string &face, float size,
@@ -538,7 +543,7 @@ ImageFont*    FontManager::getClosestRealSize(int faceID, float desiredSize, flo
   if (!canScale || desiredSize < 14.0f) {
     // get the next biggest font size from requested
     if (!font) {
-      DEBUG2("Could not find applicable font size for sizing; font face ID %d, "
+      logDebugMessage(2,"Could not find applicable font size for sizing; font face ID %d, "
 	     "requested size %f\n", faceID, desiredSize);
       return NULL;
     }
