@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -324,10 +324,10 @@ static RemotePlayer *findBestTarget()
 
       //perform a draft that has us chase the proposed opponent if they have our flag
       if (World::getWorld()->allowTeamFlags() &&
-	  (myTank->getTeam() == RedTeam && player[t]->getFlag() == Flags::RedTeam) ||
-	  (myTank->getTeam() == GreenTeam && player[t]->getFlag() == Flags::GreenTeam) ||
-	  (myTank->getTeam() == BlueTeam && player[t]->getFlag() == Flags::BlueTeam) ||
-	  (myTank->getTeam() == PurpleTeam && player[t]->getFlag() == Flags::PurpleTeam)) {
+	  (((myTank->getTeam() == RedTeam) && (player[t]->getFlag() == Flags::RedTeam)) ||
+	  ((myTank->getTeam() == GreenTeam) && (player[t]->getFlag() == Flags::GreenTeam)) ||
+	  ((myTank->getTeam() == BlueTeam) && (player[t]->getFlag() == Flags::BlueTeam)) ||
+	  ((myTank->getTeam() == PurpleTeam) && (player[t]->getFlag() == Flags::PurpleTeam)))) {
 	target = player[t];
 	break;
       }
