@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -98,6 +98,16 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option->update();
   listHUD.push_back(option);
 
+  option = new HUDuiList;
+  option->setFontFace(fontFace);
+  option->setLabel("AntiFlicker:");
+  option->setCallback(callback, (void*)"R");
+  options = &option->getList();
+  options->push_back(std::string("Off"));
+  options->push_back(std::string("On"));
+  option->update();
+  listHUD.push_back(option);
+
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Anisotropic:");
@@ -110,9 +120,9 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     if (maxAnisotropy > 1) {
       options->push_back(std::string("Off"));
       for (int i = 1; i < maxAnisotropy; i++) {
-        char buffer[16];
-        snprintf(buffer, 16, "%i/%i", i + 1, maxAnisotropy);
-        options->push_back(std::string(buffer));
+	char buffer[16];
+	snprintf(buffer, 16, "%i/%i", i + 1, maxAnisotropy);
+	options->push_back(std::string(buffer));
       }
     } else {
       options->push_back(std::string("Unavailable"));
@@ -122,7 +132,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   }
 #else
   options->push_back(std::string("Unavailable"));
-#endif  
+#endif
   option->update();
   listHUD.push_back(option);
 
@@ -308,6 +318,7 @@ void			DisplayMenu::resize(int _width, int _height)
       ((HUDuiList*)listHUD[i++])->setIndex(0);
     }
     ((HUDuiList*)listHUD[i++])->setIndex(tm.getMaxFilter());
+    ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("remapTexCoords") ? 1 : 0);
     int aniso = BZDB.evalInt("aniso");
     aniso = (aniso < 1) ? 1 : aniso;
     ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("aniso") - 1);
@@ -391,6 +402,11 @@ void			DisplayMenu::callback(HUDuiControl* w, void* data) {
     sceneRenderer->notifyStyleChange();
     break;
   }
+  case 'R': {
+    BZDB.setBool("remapTexCoords", list->getIndex() == 1);
+    setSceneDatabase();
+    break;
+  }
   case 'A': {
     int aniso = list->getIndex() + 1;
     BZDB.setInt("aniso", aniso);
