@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,9 +20,6 @@
 #include "HUDuiDefaultKey.h"
 
 class JoinMenu;
-#ifdef HAVE_KRB5
-class LoginMenu;
-#endif
 class OptionsMenu;
 class QuitMenu;
 
@@ -38,7 +35,7 @@ public:
   void resize(int width, int height);
   void createControls();
 
-  static const int getFontFace();
+  static int getFontFace();
 
 private:
 
@@ -53,9 +50,6 @@ private:
   HUDuiControl*	quit;
 
   JoinMenu*	joinMenu;
-#ifdef HAVE_KRB5
-  LoginMenu*	loginMenu;
-#endif
   OptionsMenu*	optionsMenu;
   QuitMenu*	quitMenu;
 };
